@@ -8,6 +8,7 @@ use IPC::Cmd qw[can_run];
 use Data::Dumper;
 use Capture::Tiny ':all';
 use Slurp;
+use Text::Diff;
 
 our $case = "test001";
 
@@ -56,13 +57,14 @@ EOF
 
     for(my $batch=1; $batch < $obj->batch_counter; $batch++){
 
+    my $counter = sprintf ("%03d", $batch);
 my $expected =<<EOF;
 #!/bin/bash
 #
 #SBATCH --share
 #SBATCH --get-user-env
-#SBATCH --job-name=job_$batch
-#SBATCH --output=job_$batch.log
+#SBATCH --job-name=$counter\_job
+#SBATCH --output=$counter\_job.log
 
 
 
@@ -75,13 +77,15 @@ my $expected =<<EOF;
 
 
 cd $cwd
-mcerunner.pl --procs 4 --infile $Bin/example/$case/subs/job_$batch.in --outdir $Bin/example/$case/subs --logname job_$batch
+mcerunner.pl --procs 4 --infile $Bin/example/$case/subs/$counter\_job.in --outdir $Bin/example/$case/subs --logname $counter\_job
 EOF
-        my $file = slurp("$Bin/example/$case/subs/job_$batch.sh");
-        $file =~ s/#SBATCH --output=($Bin\/example\/$case\/subs\/\w.*)\/job_$batch.log/#SBATCH --output=job_$batch.log/g;
+        my $file = slurp("$Bin/example/$case/subs/$counter"."_job.sh");
+        $file =~ s/#SBATCH --output=($Bin\/example\/$case\/subs\/\w.*)\/$counter\_job.log/#SBATCH --output=$counter\_job.log/g;
+
+        my $diff = diff \$file, \$expected;
         is($file, $expected, "Batch $batch matches");
 
-        $file = slurp("$Bin/example/$case/subs/job_$batch.in");
+        $file = slurp("$Bin/example/$case/subs/$counter\_job.in");
         $expected = $href->{$batch};
         is($file, $expected, "Job file $batch matches");
     }
