@@ -57,13 +57,14 @@ EOF
 
     for(my $batch=1; $batch < $obj->batch_counter; $batch++){
 
+    my $counter = sprintf ("%03d", $batch);
 my $expected =<<EOF;
 #!/bin/bash
 #
 #SBATCH --share
 #SBATCH --get-user-env
-#SBATCH --job-name=job_$batch
-#SBATCH --output=job_$batch.log
+#SBATCH --job-name=$counter\_job
+#SBATCH --output=$counter\_job.log
 
 
 
@@ -76,16 +77,30 @@ my $expected =<<EOF;
 
 
 cd $cwd
-mcerunner.pl --procs 4 --infile $Bin/example/$case/subs/job_$batch.in --outdir $Bin/example/$case/subs --logname job_$batch
+mcerunner.pl --procs 4 --infile $Bin/example/$case/subs/$counter\_job.in --outdir $Bin/example/$case/subs --logname $counter\_job
 EOF
-        my $file = slurp("$Bin/example/$case/subs/job_$batch.sh");
-        $file =~ s/#SBATCH --output=($Bin\/example\/$case\/subs\/\w.*)\/job_$batch.log/#SBATCH --output=job_$batch.log/g;
+        my $file = slurp("$Bin/example/$case/subs/$counter\_job.sh");
+        $file =~ s/#SBATCH --output=($Bin\/example\/$case\/subs\/\w.*)\/$counter\_job.log/#SBATCH --output=$counter\_job.log/g;
         my $diff = diff \$file, \$expected;
-        #diag($diff);
+        #if($diff){
+            #diag("BATCHFILE DIFF IS");
+            #diag($diff);
+        #}
+        #else{
+            #diag("There is no DIFF");
+        #}
         is($file, $expected, "Batch $batch matches");
 
-        $file = slurp("$Bin/example/$case/subs/job_$batch.in");
+        $file = slurp("$Bin/example/$case/subs/$counter\_job.in");
         $expected = $href->{$batch};
+        $diff = diff \$file, \$expected;
+        #if($diff){
+            #diag("JOBFILE DIFF IS");
+            #diag($diff);
+        #}
+        #else{
+            #diag("There is no DIFF");
+        #}
         is($file, $expected, "Job file $batch matches");
     }
 
